@@ -170,7 +170,7 @@
 #define HAVE_DECL_MADVISE 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
 #define HAVE_MALLINFO 1
-/* #undef HAVE_MALLINFO2 */
+#define HAVE_MALLINFO2 1
 /* #undef HAVE_MALLOC_ZONE */
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -179,6 +179,7 @@
 #define HAVE_MLOCKALL 1
 #define HAVE_MMAP 1
 #define HAVE_MMAP64 1
+#define HAVE_MPROTECT 1
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
@@ -528,17 +529,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 5
+#define MYSQL_VERSION_MINOR 7
+#define MYSQL_VERSION_PATCH 3
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.5"
+#define PACKAGE_STRING "MySQL Server 10.7.3"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.5"
-#define VERSION "10.6.5"
+#define PACKAGE_VERSION "10.7.3"
+#define VERSION "10.7.3"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
